@@ -1,12 +1,10 @@
 var class_ogre_1_1_r_t_shader_1_1_program_writer_manager =
 [
-    [ "FactoryMap", "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#a978eec10b5b76ddddf06a615ecd97563", null ],
     [ "ProgramWriterManager", "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#aa7d6b319ff45bc9861dba292f9b2ff7a", null ],
     [ "~ProgramWriterManager", "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#a97fa340b976122ebe93939ea47580bc8", null ],
-    [ "addFactory", "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#a58504fc8e566b0172c448249f724522d", null ],
-    [ "removeFactory", "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#aa85306b68773fc269737df0ba894f996", null ],
+    [ "addProgramWriter", "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#a73b6e78fa3c138c4987b96aa2a7c3118", null ],
     [ "isLanguageSupported", "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#aab32a8bee0c51620b07d3e1b80eca028", null ],
-    [ "createProgramWriter", "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#a9fda1ee444289e2c482ec8b06ab36820", null ],
+    [ "getProgramWriter", "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#a524ef661f98d60ee7d7422828a2b31bd", null ],
     [ "getSingleton", "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#a63350ccbb6834028260b2642c9509bb7", null ],
     [ "getSingletonPtr", "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#ad88f08e88099432ae43500912c885b3a", null ]
 ];
\ No newline at end of file
