@@ -1,5 +1,24 @@
 var NAVTREEINDEX9 =
 {
+"class_ogre_1_1_colour_image_affector.html#a7118e0cf5c7cefcbbf004580add48ae5":[7,0,0,62,1],
+"class_ogre_1_1_colour_image_affector.html#a712aea5134dc25d81d92a0f8d217859f":[6,0,1,62,2],
+"class_ogre_1_1_colour_image_affector.html#a712aea5134dc25d81d92a0f8d217859f":[7,0,0,62,2],
+"class_ogre_1_1_colour_image_affector.html#abd1161e46d005429f64883cfe0bdaea3":[6,0,1,62,3],
+"class_ogre_1_1_colour_image_affector.html#abd1161e46d005429f64883cfe0bdaea3":[7,0,0,62,3],
+"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html":[6,0,1,62,0],
+"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html":[7,0,0,62,0],
+"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#aa6baf8872837f8c1bf0145e2ee433c02":[6,0,1,62,0,0],
+"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#aa6baf8872837f8c1bf0145e2ee433c02":[7,0,0,62,0,0],
+"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#acbfa224b7d10bd20b83002856c07a9f0":[6,0,1,62,0,1],
+"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#acbfa224b7d10bd20b83002856c07a9f0":[7,0,0,62,0,1],
+"class_ogre_1_1_colour_interpolator_affector.html":[6,0,1,63],
+"class_ogre_1_1_colour_interpolator_affector.html":[7,0,0,63],
+"class_ogre_1_1_colour_interpolator_affector.html#a055f5f5bbe49e66d40c84c257e78b340":[6,0,1,63,9],
+"class_ogre_1_1_colour_interpolator_affector.html#a055f5f5bbe49e66d40c84c257e78b340":[7,0,0,63,9],
+"class_ogre_1_1_colour_interpolator_affector.html#a23342275feed700c10a601e5edb17152":[6,0,1,63,2],
+"class_ogre_1_1_colour_interpolator_affector.html#a23342275feed700c10a601e5edb17152":[7,0,0,63,2],
+"class_ogre_1_1_colour_interpolator_affector.html#a3534e0793f6d1aa89477c58e16a822a9":[6,0,1,63,4],
+"class_ogre_1_1_colour_interpolator_affector.html#a3534e0793f6d1aa89477c58e16a822a9":[7,0,0,63,4],
 "class_ogre_1_1_colour_interpolator_affector.html#a4ebe10757356bf52a3debdfffa4c9b80":[6,0,1,63,6],
 "class_ogre_1_1_colour_interpolator_affector.html#a4ebe10757356bf52a3debdfffa4c9b80":[7,0,0,63,6],
 "class_ogre_1_1_colour_interpolator_affector.html#a7f3dfd3656eb976353b98ed34319d60a":[6,0,1,63,7],
@@ -29,12 +48,14 @@ var NAVTREEINDEX9 =
 "class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html#ab7927db974a724cdd9798e597a398c7f":[6,0,1,63,1,1],
 "class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html#ab7927db974a724cdd9798e597a398c7f":[7,0,0,63,1,1],
 "class_ogre_1_1_colour_value.html":[5,0,2,5],
-"class_ogre_1_1_colour_value.html#a00384a789ac354ea8dd252c62cb17aa4":[5,0,2,5,38],
+"class_ogre_1_1_colour_value.html#a0b3c6d7aba3e2879c5bff3d864241584":[5,0,2,5,34],
+"class_ogre_1_1_colour_value.html#a0f66d1fae35f9f2a13ce26349fb71a79":[5,0,2,5,35],
 "class_ogre_1_1_colour_value.html#a11c1455b2d4bc0bb0fc4fb20ba6fa099":[5,0,2,5,30],
 "class_ogre_1_1_colour_value.html#a13fbd050af26b8bd549ccb46aa699e07":[5,0,2,5,41],
 "class_ogre_1_1_colour_value.html#a1570846ab08c04adbd3d58cd2aa1c860":[5,0,2,5,16],
 "class_ogre_1_1_colour_value.html#a170729634175d1cea8bd8c882bdde71e":[5,0,2,5,6],
 "class_ogre_1_1_colour_value.html#a176de8fc97c2f6392b585830286dfe49":[5,0,2,5,27],
+"class_ogre_1_1_colour_value.html#a1bcb3611eec7ec5ce68967e6023acb6d":[5,0,2,5,37],
 "class_ogre_1_1_colour_value.html#a1cf6b673afb17fe889e4255a938c3cbb":[5,0,2,5,7],
 "class_ogre_1_1_colour_value.html#a21875c1d92c3ad0cba9cafd5776f42a0":[5,0,2,5,13],
 "class_ogre_1_1_colour_value.html#a27b26fbfa1098376c47e337192d04f27":[5,0,2,5,5],
@@ -43,30 +64,28 @@ var NAVTREEINDEX9 =
 "class_ogre_1_1_colour_value.html#a435d20368c31728dea21469d1db036f6":[5,0,2,5,23],
 "class_ogre_1_1_colour_value.html#a438810466e8d1c29eb6b84f372ceb2e7":[5,0,2,5,4],
 "class_ogre_1_1_colour_value.html#a4825d1fb89ea5aae7f2e18e108aa7f23":[5,0,2,5,3],
+"class_ogre_1_1_colour_value.html#a4b5005bc7a691be69292a06fdab037fd":[5,0,2,5,38],
 "class_ogre_1_1_colour_value.html#a5605ea48f88f611955bdd0c96150a8e5":[5,0,2,5,8],
 "class_ogre_1_1_colour_value.html#a5b0ed5d4289ec1f56295380a0a334e4f":[5,0,2,5,32],
 "class_ogre_1_1_colour_value.html#a6141ef6c5e433c9e59807222f7fa79fe":[5,0,2,5,33],
-"class_ogre_1_1_colour_value.html#a67ef25ecd0fa97e7e51e5bd87b29ae65":[5,0,2,5,39],
 "class_ogre_1_1_colour_value.html#a6e086633637e335238d517e0ec9f2cd2":[5,0,2,5,40],
+"class_ogre_1_1_colour_value.html#a783132a039d3d5bbccedbcea77ff3c79":[5,0,2,5,0],
 "class_ogre_1_1_colour_value.html#a788549742c1f030184c53008423c7b9c":[5,0,2,5,21],
 "class_ogre_1_1_colour_value.html#a7c80a19ac61f97f217d5b39d8f1dd39b":[5,0,2,5,2],
 "class_ogre_1_1_colour_value.html#a7ced6ef07e9a1e6de8ea50ef824ed9b1":[5,0,2,5,12],
 "class_ogre_1_1_colour_value.html#a7f38270891b9602c9951fe0d0a720311":[5,0,2,5,28],
 "class_ogre_1_1_colour_value.html#a7f86f695818890ba2f857618b1af9f59":[5,0,2,5,11],
-"class_ogre_1_1_colour_value.html#a7f8a06f2a9dd645417c36b560f496c1a":[5,0,2,5,35],
 "class_ogre_1_1_colour_value.html#a8242cd224705e15b9e1533fe83c290c7":[5,0,2,5,18],
 "class_ogre_1_1_colour_value.html#a854058a76927880ae345ac1c465f9713":[5,0,2,5,43],
 "class_ogre_1_1_colour_value.html#a8638135228e5ddcd1dc7db320542cf72":[5,0,2,5,19],
 "class_ogre_1_1_colour_value.html#a8bf64c97ca14f64127cb3f5f95e856cf":[5,0,2,5,22],
-"class_ogre_1_1_colour_value.html#a8eba66b2908f44f00f8d9c9ec25877de":[5,0,2,5,36],
 "class_ogre_1_1_colour_value.html#aa807f795d563dbf32601b20925cd46d4":[5,0,2,5,1],
 "class_ogre_1_1_colour_value.html#aa8bbc191b3de291abe02fce7e0d619c2":[5,0,2,5,14],
+"class_ogre_1_1_colour_value.html#aabc748c7dbf62da85d6016c073314e7b":[5,0,2,5,39],
 "class_ogre_1_1_colour_value.html#aae078d77b654f76e3b760174f93474ec":[5,0,2,5,42],
 "class_ogre_1_1_colour_value.html#aaf5cc43741699cd3c0c7e81a1dc349a2":[5,0,2,5,9],
-"class_ogre_1_1_colour_value.html#ab9c2a36f53ac599850f1cf8b822f750d":[5,0,2,5,37],
-"class_ogre_1_1_colour_value.html#abc5d5f80d4d99438863cc808169283b5":[5,0,2,5,34],
+"class_ogre_1_1_colour_value.html#ab67f75eb63c2ee10cb6e874219b01b67":[5,0,2,5,36],
 "class_ogre_1_1_colour_value.html#ac8e68543a87fcc6e1c0789c052fa45ba":[5,0,2,5,15],
-"class_ogre_1_1_colour_value.html#acc033c4828ad9f7469269933d24850f5":[5,0,2,5,0],
 "class_ogre_1_1_colour_value.html#ad33e4ae6c7e6d223545613c4991c91ed":[5,0,2,5,24],
 "class_ogre_1_1_colour_value.html#ad46a3cf5b7e9781aaee892d23458ebd0":[5,0,2,5,26],
 "class_ogre_1_1_colour_value.html#adcc45721a4be58eafb2a3bb6df4f73b2":[5,0,2,5,25],
@@ -209,45 +228,26 @@ var NAVTREEINDEX9 =
 "class_ogre_1_1_composition_technique.html#af221a1809b2de447c7036dd356026ad5":[5,0,1,7,27],
 "class_ogre_1_1_composition_technique.html#af6b63a9d4592c48d2389525148a334ee":[5,0,1,7,3],
 "class_ogre_1_1_composition_technique_1_1_texture_definition.html":[5,0,1,7,0],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a07a1f192baf1bb43445dd40bbbaef114":[5,0,1,7,0,11],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a07a1f192baf1bb43445dd40bbbaef114":[5,0,1,7,0,12],
 "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a23d1b9553769ca1f4e47175a567fcf0c":[5,0,1,7,0,1],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a2b3a7551a57b77fde8c23de7267b2056":[5,0,1,7,0,6],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a2b3a7551a57b77fde8c23de7267b2056":[5,0,1,7,0,7],
 "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a438d2780a5dfe0ac83309b0b9e7dde96":[5,0,1,7,0,3],
 "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a46b4ede7400302f6d58e03d1eb4489ae":[5,0,1,7,0,4],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a5c71286e9daa688d6028deb524c15ddc":[5,0,1,7,0,7],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a5c71286e9daa688d6028deb524c15ddc":[5,0,1,7,0,8],
 "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a7e371a5590972522e7f8024295bb8a59":[5,0,1,7,0,0],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a8826739f93ea3bb356c4a1bb5b5b008c":[5,0,1,7,0,14],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a90341172974dbdea53d010c4d5aa90da":[5,0,1,7,0,13],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a99163323a7ab7d6b661f538b17c8f97b":[5,0,1,7,0,8],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#aa9c8a54bdaa418233c6f10c3a8a2eb98":[5,0,1,7,0,12],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a8826739f93ea3bb356c4a1bb5b5b008c":[5,0,1,7,0,15],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a90341172974dbdea53d010c4d5aa90da":[5,0,1,7,0,14],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a961b6a77bc1f93094da60c68ce7124f6":[5,0,1,7,0,6],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a99163323a7ab7d6b661f538b17c8f97b":[5,0,1,7,0,9],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#aa9c8a54bdaa418233c6f10c3a8a2eb98":[5,0,1,7,0,13],
 "class_ogre_1_1_composition_technique_1_1_texture_definition.html#abbbb4c6b2ea75b413ff5534be536ad73":[5,0,1,7,0,5],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#acdc503bc2adeee31d32988c6c994c0d6":[5,0,1,7,0,9],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#acdc503bc2adeee31d32988c6c994c0d6":[5,0,1,7,0,10],
 "class_ogre_1_1_composition_technique_1_1_texture_definition.html#ae59f6efc2a9d0bc5cf539c647351848d":[5,0,1,7,0,2],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#af7cf8abd5790419f08b59519b3bb3374":[5,0,1,7,0,10],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#af7cf8abd5790419f08b59519b3bb3374":[5,0,1,7,0,11],
 "class_ogre_1_1_compositor.html":[5,0,1,8],
 "class_ogre_1_1_compositor.html#a1f3a6209ce89a4105719c26e0b2a5f46":[5,0,1,8,2],
 "class_ogre_1_1_compositor.html#a34a3a5086152382d77a85c25fbabb1be":[5,0,1,8,0],
 "class_ogre_1_1_compositor.html#a446dd4a5fed791283a79d6acd9936d55":[5,0,1,8,15],
 "class_ogre_1_1_compositor.html#a52653a85d40ae889556707320a784d3e":[5,0,1,8,12],
-"class_ogre_1_1_compositor.html#a57a6ab020e5ac812bb96aa59b1497fbd":[5,0,1,8,8],
-"class_ogre_1_1_compositor.html#a65cd9c6af5f17b32283be24e0b13010f":[5,0,1,8,9],
-"class_ogre_1_1_compositor.html#a74f8cab4f5407b59a30160a1f8309cee":[5,0,1,8,14],
-"class_ogre_1_1_compositor.html#a78ac5745673e6e9f44a866ef016710cd":[5,0,1,8,3],
-"class_ogre_1_1_compositor.html#a7f8ef525639ebc764e0be2dfa1349dfd":[5,0,1,8,11],
-"class_ogre_1_1_compositor.html#aa22940bfe5308327d7f00aea0279deab":[5,0,1,8,13],
-"class_ogre_1_1_compositor.html#aae47eb9cabec8ad5c8b40a0dd0e8180d":[5,0,1,8,5],
-"class_ogre_1_1_compositor.html#acc029ae8cf6f0db569d8328621c6cd50":[5,0,1,8,1],
-"class_ogre_1_1_compositor.html#acf1dec61d4fc0b3001ed0cf4eb7e3969":[5,0,1,8,10],
-"class_ogre_1_1_compositor.html#acfdba392e0274fdbd0e4d14948bebc38":[5,0,1,8,6],
-"class_ogre_1_1_compositor.html#adf336074a45c59d05b585f0e6f745ed3":[5,0,1,8,16],
-"class_ogre_1_1_compositor.html#aed7c5f927e625cf58f65a50c9c55abe4":[5,0,1,8,4],
-"class_ogre_1_1_compositor.html#af5c1adab5d0aa7bae1374cd971162c8c":[5,0,1,8,7],
-"class_ogre_1_1_compositor_chain.html":[5,0,1,9],
-"class_ogre_1_1_compositor_chain.html#a0301254bb0cd91ca135805638301ad25":[5,0,1,9,21],
-"class_ogre_1_1_compositor_chain.html#a0786570dbe0567f781db42c64cdc0864":[5,0,1,9,22],
-"class_ogre_1_1_compositor_chain.html#a0c5a67e7aeb3f74242a45972f30073eb":[5,0,1,9,24],
-"class_ogre_1_1_compositor_chain.html#a136bcc91dece7d0c020c6bf4e635a2f3":[5,0,1,9,5],
-"class_ogre_1_1_compositor_chain.html#a1495dde8bb681d9f10563a7d3bc90581":[5,0,1,9,16],
-"class_ogre_1_1_compositor_chain.html#a16acff0bca06c03a0b3664032631dd5f":[5,0,1,9,6],
-"class_ogre_1_1_compositor_chain.html#a1e3e30292bbae6d7191bb1c4b8a4d6fb":[5,0,1,9,23]
+"class_ogre_1_1_compositor.html#a57a6ab020e5ac812bb96aa59b1497fbd":[5,0,1,8,8]
 };
