@@ -107,7 +107,7 @@ var searchData=
   ['to_20the_20overlay_104',['Adding elements to the overlay',['../_overlay-_scripts.html#Adding-elements-to-the-overlay',1,'']]],
   ['to_20the_20shadow_20mapping_20algorithm_105',['Introduction to the Shadow Mapping Algorithm',['../_shadow_mapping_ogre.html#ShadowMappingIntro',1,'']]],
   ['to_20try_106',['Things to Try',['../trays.html#things-to-try',1,'']]],
-  ['to_20use_20dotscene_107',['How to use DotScene',['..//build/ogre/src/ogre-14.4.1/PlugIns/DotScene/README.md#autotoc_md11',1,'']]],
+  ['to_20use_20dotscene_107',['How to use DotScene',['..//startdir/src/ogre-14.4.1/PlugIns/DotScene/README.md#autotoc_md11',1,'']]],
   ['to_20use_20it_108',['How to use it',['../volume.html#howto',1,'']]],
   ['to_20use_20it_20for_20non_20programmers_109',['How to use it for non-programmers',['../meshlod-generator.html#meshlod-nonprog',1,'']]],
   ['to_20use_20it_20for_20programmers_110',['How to use it for programmers',['../meshlod-generator.html#meshlod-prog',1,'']]],
