@@ -6,7 +6,7 @@ var searchData=
   ['what_20is_20batch_20fragmentation_3',['What is batch fragmentation?',['../_what_is_instancing.html#InstancingDefragmentingBatchesIntro',1,'']]],
   ['what_20is_20cmake_4',['What is CMake?',['../building-ogre.html#autotoc_md259',1,'']]],
   ['what_20is_20deferred_20shading_5',['What is Deferred Shading?',['../deferred.html#what',1,'']]],
-  ['what_20is_20dotscene_6',['What is DotScene?',['..//build/ogre/src/ogre-14.4.1/PlugIns/DotScene/README.md#autotoc_md9',1,'']]],
+  ['what_20is_20dotscene_6',['What is DotScene?',['..//startdir/src/ogre-14.4.1/PlugIns/DotScene/README.md#autotoc_md9',1,'']]],
   ['what_20is_20this_7',['What is this?',['../index.html#autotoc_md22',1,'']]],
   ['why_20two_20subtypes_8',['Why two subtypes?',['../_animation.html#autotoc_md54',1,'']]],
   ['widgets_9',['Widgets',['../trays.html#special-widgets',1,'Special Widgets'],['../trays.html#widgets',1,'Widgets']]],
