@@ -49,7 +49,7 @@ var searchData=
   ['buffers_46',['buffers',['../_compositor-_scripts.html#autotoc_md84',1,'buffers'],['../_hardware-_buffers.html#Locking-buffers',1,'Locking buffers']]],
   ['buffers_20directly_47',['Using vertex and index buffers directly',['../manual-mesh-creation.html#autotoc_md300',1,'']]],
   ['buffers_20in_20mesh_20shaders_48',['Buffers in Mesh Shaders',['../_high-level-_programs.html#GLSL-Mesh-Shaders',1,'']]],
-  ['bugs_49',['KNOWN BUGS',['..//build/ogre/src/ogre-14.4.1/PlugIns/PCZSceneManager/docs/readme.md#autotoc_md8',1,'']]],
+  ['bugs_49',['KNOWN BUGS',['..//startdir/src/ogre-14.4.1/PlugIns/PCZSceneManager/docs/readme.md#autotoc_md8',1,'']]],
   ['build_20environment_50',['Preparing the build environment',['../building-ogre.html#autotoc_md260',1,'']]],
   ['building_51',['Building',['../building-ogre.html#autotoc_md266',1,'']]],
   ['building_20ogre_52',['Guide to building OGRE',['../building-ogre.html',1,'tutorials']]],
