@@ -86,12 +86,12 @@ var searchData=
   ['creating_20an_20index_20buffer_83',['Creating an Index Buffer',['../_hardware-_buffers.html#autotoc_md243',1,'']]],
   ['creating_20custom_20shader_20extensions_84',['Creating custom shader extensions',['../rtss.html#creating-extensions',1,'']]],
   ['creating_20more_20lights_85',['Creating More Lights',['../tut__lights_cameras_shadows.html#CreatingMoreLights',1,'']]],
-  ['creating_20objects_20entities_86',['CREATING OBJECTS/ENTITIES',['..//build/ogre/src/ogre-14.4.1/PlugIns/PCZSceneManager/docs/readme.md#autotoc_md6',1,'']]],
-  ['creating_20portals_87',['CREATING PORTALS',['..//build/ogre/src/ogre-14.4.1/PlugIns/PCZSceneManager/docs/readme.md#autotoc_md4',1,'']]],
+  ['creating_20objects_20entities_86',['CREATING OBJECTS/ENTITIES',['..//startdir/src/ogre-14.4.1/PlugIns/PCZSceneManager/docs/readme.md#autotoc_md6',1,'']]],
+  ['creating_20portals_87',['CREATING PORTALS',['..//startdir/src/ogre-14.4.1/PlugIns/PCZSceneManager/docs/readme.md#autotoc_md4',1,'']]],
   ['creating_20the_20g_20buffer_88',['Creating the G-Buffer',['../deferred.html#creating',1,'']]],
   ['creating_20the_20shader_20based_20technique_89',['Creating the shader based technique',['../rtss.html#rtssTech',1,'']]],
   ['creating_20the_20vertex_20buffer_90',['Creating the Vertex Buffer',['../_hardware-_buffers.html#Creating-the-Vertex-Buffer',1,'']]],
-  ['creating_20zones_91',['CREATING ZONES',['..//build/ogre/src/ogre-14.4.1/PlugIns/PCZSceneManager/docs/readme.md#autotoc_md3',1,'']]],
+  ['creating_20zones_91',['CREATING ZONES',['..//startdir/src/ogre-14.4.1/PlugIns/PCZSceneManager/docs/readme.md#autotoc_md3',1,'']]],
   ['creation_92',['creation',['../manual-mesh-creation.html',1,'Manual mesh creation'],['../_compositor-_scripts.html#Compositor-API',1,'Programmatic creation'],['../_high-level-_programs.html#GpuProgram-API',1,'Programmatic creation']]],
   ['creation_20of_20a_20csg_20tree_93',['Manual creation of a CSG-Tree',['../volume.html#creation',1,'']]],
   ['cross_20compiling_94',['Cross-Compiling',['../building-ogre.html#autotoc_md268',1,'']]],
