@@ -21,7 +21,7 @@ var searchData=
   ['horz_5falign_18',['horz_align',['../_overlay-_scripts.html#autotoc_md99',1,'']]],
   ['how_20ogre_20works_19',['How Ogre Works',['../tut__first_scene.html#howogreworks',1,'']]],
   ['how_20to_20enable_20overlays_20',['How to Enable Overlays',['../_the-_core-_objects.html#autotoc_md28',1,'']]],
-  ['how_20to_20use_20dotscene_21',['How to use DotScene',['..//build/ogre/src/ogre-14.4.1/PlugIns/DotScene/README.md#autotoc_md11',1,'']]],
+  ['how_20to_20use_20dotscene_21',['How to use DotScene',['..//startdir/src/ogre-14.4.1/PlugIns/DotScene/README.md#autotoc_md11',1,'']]],
   ['how_20to_20use_20it_22',['How to use it',['../volume.html#howto',1,'']]],
   ['how_20to_20use_20it_20for_20non_20programmers_23',['How to use it for non-programmers',['../meshlod-generator.html#meshlod-nonprog',1,'']]],
   ['how_20to_20use_20it_20for_20programmers_24',['How to use it for programmers',['../meshlod-generator.html#meshlod-prog',1,'']]],
