@@ -33,7 +33,7 @@ var searchData=
   ['loading_30',['Background Resource Loading',['../background-resource.html',1,'tutorials']]],
   ['loading_20a_20heightmap_31',['Loading a heightmap',['../tut__terrain_sky_fog.html#bt3Heightmap',1,'']]],
   ['loading_20bar_32',['Loading Bar',['../trays.html#autotoc_md330',1,'']]],
-  ['loading_20initialization_33',['LOADING &amp;amp; INITIALIZATION',['..//build/ogre/src/ogre-14.4.1/PlugIns/PCZSceneManager/docs/readme.md#autotoc_md2',1,'']]],
+  ['loading_20initialization_33',['LOADING &amp;amp; INITIALIZATION',['..//startdir/src/ogre-14.4.1/PlugIns/PCZSceneManager/docs/readme.md#autotoc_md2',1,'']]],
   ['loading_20label_34',['Loading Label',['../tut__terrain_sky_fog.html#bt3LoadingLabel',1,'']]],
   ['loading_20overview_35',['Loading overview',['../tut__terrain_sky_fog.html#bt3Overview',1,'']]],
   ['loading_20scripts_36',['Loading scripts',['../_scripts.html#autotoc_md63',1,'']]],
